"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDpPtCorrection = void 0;
const deep_map_1 = __importDefault(require("../deep-map"));
const dpPtCorrectionImplementation = (definedPixelRatio = 1, definedFontScale = 1) => (value) => {
    const validResponsiveRegex = /^(\-?\d+(?:\.\d{1,3})?)@(dp|pt)$/;
    const PX_PT_RATIO = 1.328;
    let result = value;
    if (!validResponsiveRegex.test(value)) {
        return value;
    }
    const regexExecResult = validResponsiveRegex.exec(value);
    if (regexExecResult) {
        const size = parseFloat(regexExecResult[1]);
        const selector = regexExecResult[2];
        switch (selector) {
            case 'dp':
                result = size * definedPixelRatio;
                break;
            case 'pt':
                result = size * PX_PT_RATIO * definedFontScale;
                break;
        }
    }
    return result;
};
const dpPtCorrection = (definedPixelRatio = 1, definedFontScale = 1) => (styles) => {
    return deep_map_1.default(styles, dpPtCorrectionImplementation(definedPixelRatio, definedFontScale));
};
const getDpPtCorrection = (pixelRatio, fontScale) => dpPtCorrection(pixelRatio, fontScale);
exports.getDpPtCorrection = getDpPtCorrection;
//# sourceMappingURL=dpPtCorrection.js.map